# Reed-Muller in Python

This is a research project I completed for a course at Carleton University, "Finite Fields and Coding Theory."

This comprises a paper that attempts to present Reed-Muller codes in a simplistic way, and includes a Python implementation of
encoding and decoding (using majority logic) using Reed-Muller codes.

Code now works on both Python 2 and Python 3.
